@@ -118,6 +118,7 @@ func (r *ProtocolIncus) UseProject(name string) InstanceServer {
 		project:              name,
 		eventConns:           make(map[string]*websocket.Conn),  // New project specific listener conns.
 		eventListeners:       make(map[string][]*EventListener), // New project specific listeners.
+		skipEvents:           r.skipEvents,
 		oidcClient:           r.oidcClient,
 	}
 }
@@ -141,6 +142,7 @@ func (r *ProtocolIncus) UseTarget(name string) InstanceServer {
 		project:              r.project,
 		eventConns:           make(map[string]*websocket.Conn),  // New target specific listener conns.
 		eventListeners:       make(map[string][]*EventListener), // New target specific listeners.
+		skipEvents:           r.skipEvents,
 		oidcClient:           r.oidcClient,
 		clusterTarget:        name,
 	}
@@ -571,5 +573,33 @@ func (r *ProtocolIncus) ApplyServerPreseed(config api.InitPreseed) error {
 		}
 	}
 
+	// Apply cluster group configurations.
+	if len(config.Server.ClusterGroups) > 0 {
+		for _, clusterGroup := range config.Server.ClusterGroups {
+			// Check if it already exists.
+			existing, etag, err := r.GetClusterGroup(clusterGroup.Name)
+			if err == nil && existing != nil {
+				// Keep existing members if none specified (set of empty slice to empty).
+				if clusterGroup.Members == nil {
+					clusterGroup.Members = existing.Members
+				}
+
+				// Update the existing group.
+				err = r.UpdateClusterGroup(clusterGroup.Name, clusterGroup.ClusterGroupPut, etag)
+				if err != nil {
+					return fmt.Errorf("Failed to update cluster group")
+				}
+
+				continue
+			}
+
+			// Create the new group.
+			err = r.CreateClusterGroup(clusterGroup)
+			if err != nil {
+				return fmt.Errorf("Failed to create cluster group")
+			}
+		}
+	}
+
 	return nil
 }
