@@ -21,5 +21,9 @@ func (c *cmdAdmin) Command() *cobra.Command {
 	cmd.Long = cli.FormatSection(i18n.G("Description"), i18n.G(
 		`Manage incus daemon`))
 
+	// os
+	adminOSCmd := cmdAdminOS{global: c.global}
+	cmd.AddCommand(adminOSCmd.Command())
+
 	return cmd
 }
