@@ -766,18 +766,14 @@ type cmdNetworkZoneDelete struct {
 // Command returns a cobra.Command for use with (*cobra.Command).AddCommand.
 func (c *cmdNetworkZoneDelete) Command() *cobra.Command {
 	cmd := &cobra.Command{}
-	cmd.Use = cli.Usage("delete", i18n.G("[<remote>:]<Zone>"))
+	cmd.Use = cli.Usage("delete", i18n.G("[<remote>:]<Zone> [[<remote>:]<Zone>...]"))
 	cmd.Aliases = []string{"rm", "remove"}
 	cmd.Short = i18n.G("Delete network zones")
 	cmd.Long = cli.FormatSection(i18n.G("Description"), i18n.G("Delete network zones"))
 	cmd.RunE = c.Run
 
 	cmd.ValidArgsFunction = func(_ *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
-		if len(args) == 0 {
-			return c.global.cmpNetworkZones(toComplete)
-		}
-
-		return nil, cobra.ShellCompDirectiveNoFileComp
+		return c.global.cmpNetworkZones(toComplete)
 	}
 
 	return cmd
@@ -786,31 +782,31 @@ func (c *cmdNetworkZoneDelete) Command() *cobra.Command {
 // Run runs the actual command logic.
 func (c *cmdNetworkZoneDelete) Run(cmd *cobra.Command, args []string) error {
 	// Quick checks.
-	exit, err := c.global.checkArgs(cmd, args, 1, 1)
+	exit, err := c.global.checkArgs(cmd, args, 1, -1)
 	if exit {
 		return err
 	}
 
 	// Parse remote.
-	resources, err := c.global.parseServers(args[0])
+	resources, err := c.global.parseServers(args...)
 	if err != nil {
 		return err
 	}
 
-	resource := resources[0]
+	for _, resource := range resources {
+		if resource.name == "" {
+			return errors.New(i18n.G("Missing network zone name"))
+		}
 
-	if resource.name == "" {
-		return errors.New(i18n.G("Missing network zone name"))
-	}
+		// Delete the network zone.
+		err = resource.server.DeleteNetworkZone(resource.name)
+		if err != nil {
+			return err
+		}
 
-	// Delete the network zone.
-	err = resource.server.DeleteNetworkZone(resource.name)
-	if err != nil {
-		return err
-	}
-
-	if !c.global.flagQuiet {
-		fmt.Printf(i18n.G("Network Zone %s deleted")+"\n", resource.name)
+		if !c.global.flagQuiet {
+			fmt.Printf(i18n.G("Network Zone %s deleted")+"\n", resource.name)
+		}
 	}
 
 	return nil
