@@ -7,7 +7,6 @@ import (
 	"fmt"
 	"io"
 	"os"
-	"os/exec"
 	"path/filepath"
 	"slices"
 	"strings"
@@ -18,14 +17,13 @@ import (
 	"gopkg.in/yaml.v2"
 
 	incus "github.com/lxc/incus/v6/client"
-	cli "github.com/lxc/incus/v6/internal/cmd"
 	"github.com/lxc/incus/v6/internal/ports"
 	"github.com/lxc/incus/v6/internal/server/cluster"
 	"github.com/lxc/incus/v6/internal/server/db"
 	"github.com/lxc/incus/v6/internal/server/node"
 	"github.com/lxc/incus/v6/internal/server/sys"
 	internalUtil "github.com/lxc/incus/v6/internal/util"
-	"github.com/lxc/incus/v6/shared/revert"
+	cli "github.com/lxc/incus/v6/shared/cmd"
 	"github.com/lxc/incus/v6/shared/termios"
 )
 
@@ -86,7 +84,7 @@ func (c *cmdCluster) command() *cobra.Command {
 	return cmd
 }
 
-const SegmentComment = "# Latest dqlite segment ID: %s"
+const SegmentComment = "# Latest cowsql segment ID: %s"
 
 // ClusterMember is a more human-readable representation of the db.RaftNode struct.
 type ClusterMember struct {
@@ -202,7 +200,7 @@ func (c *cmdClusterEdit) run(_ *cobra.Command, _ []string) error {
 			data = []byte(fmt.Sprintf(SegmentComment, segmentID) + "\n\n" + string(data))
 		}
 
-		content, err = textEditor("", data)
+		content, err = cli.TextEditor("", data)
 		if err != nil {
 			return err
 		}
@@ -241,7 +239,7 @@ func (c *cmdClusterEdit) run(_ *cobra.Command, _ []string) error {
 				return err
 			}
 
-			content, err = textEditor("", content)
+			content, err = cli.TextEditor("", content)
 			if err != nil {
 				return err
 			}
@@ -364,7 +362,7 @@ func (c *cmdClusterListDatabase) command() *cobra.Command {
 	cmd.Use = "list-database"
 	cmd.Aliases = []string{"ls"}
 	cmd.Short = "Print the addresses of the cluster members serving the database"
-	cmd.Flags().StringVarP(&c.flagFormat, "format", "f", "table", `Format (csv|json|table|yaml|compact), use suffix ",noheader" to disable headers and ",header" to enable it if missing, e.g. csv,header`)
+	cmd.Flags().StringVarP(&c.flagFormat, "format", "f", "table", `Format (csv|json|table|yaml|compact|markdown), use suffix ",noheader" to disable headers and ",header" to enable it if missing, e.g. csv,header`)
 
 	cmd.PreRunE = func(cmd *cobra.Command, _ []string) error {
 		return cli.ValidateFlagFormatForListOutput(cmd.Flag("format").Value.String())
@@ -532,86 +530,3 @@ Do you want to proceed? (yes/no): `)
 
 	return nil
 }
-
-// Spawn the editor with a temporary YAML file for editing configs.
-func textEditor(inPath string, inContent []byte) ([]byte, error) {
-	var f *os.File
-	var err error
-	var path string
-
-	// Detect the text editor to use
-	editor := os.Getenv("VISUAL")
-	if editor == "" {
-		editor = os.Getenv("EDITOR")
-		if editor == "" {
-			for _, p := range []string{"editor", "vi", "emacs", "nano"} {
-				_, err := exec.LookPath(p)
-				if err == nil {
-					editor = p
-					break
-				}
-			}
-			if editor == "" {
-				return []byte{}, errors.New("No text editor found, please set the EDITOR environment variable")
-			}
-		}
-	}
-
-	if inPath == "" {
-		// If provided input, create a new file
-		f, err = os.CreateTemp("", "incus_editor_")
-		if err != nil {
-			return []byte{}, err
-		}
-
-		reverter := revert.New()
-		defer reverter.Fail()
-		reverter.Add(func() {
-			_ = f.Close()
-			_ = os.Remove(f.Name())
-		})
-
-		err = os.Chmod(f.Name(), 0o600)
-		if err != nil {
-			return []byte{}, err
-		}
-
-		_, err = f.Write(inContent)
-		if err != nil {
-			return []byte{}, err
-		}
-
-		err = f.Close()
-		if err != nil {
-			return []byte{}, err
-		}
-
-		path = fmt.Sprintf("%s.yaml", f.Name())
-		err = os.Rename(f.Name(), path)
-		if err != nil {
-			return []byte{}, err
-		}
-
-		reverter.Success()
-		reverter.Add(func() { _ = os.Remove(path) })
-	} else {
-		path = inPath
-	}
-
-	cmdParts := strings.Fields(editor)
-	cmd := exec.Command(cmdParts[0], append(cmdParts[1:], path)...)
-	cmd.Stdin = os.Stdin
-	cmd.Stdout = os.Stdout
-	cmd.Stderr = os.Stderr
-	err = cmd.Run()
-	if err != nil {
-		return []byte{}, err
-	}
-
-	content, err := os.ReadFile(path)
-	if err != nil {
-		return []byte{}, err
-	}
-
-	return content, nil
-}
