@@ -31,7 +31,6 @@ import (
 	"github.com/lxc/incus/v6/internal/server/network"
 	"github.com/lxc/incus/v6/internal/server/project"
 	"github.com/lxc/incus/v6/internal/server/request"
-	"github.com/lxc/incus/v6/internal/server/resources"
 	"github.com/lxc/incus/v6/internal/server/response"
 	"github.com/lxc/incus/v6/internal/server/state"
 	localUtil "github.com/lxc/incus/v6/internal/server/util"
@@ -39,8 +38,10 @@ import (
 	"github.com/lxc/incus/v6/internal/version"
 	"github.com/lxc/incus/v6/shared/api"
 	"github.com/lxc/incus/v6/shared/logger"
+	"github.com/lxc/incus/v6/shared/resources"
 	"github.com/lxc/incus/v6/shared/revert"
 	"github.com/lxc/incus/v6/shared/util"
+	"github.com/lxc/incus/v6/shared/validate"
 )
 
 // Lock to prevent concurrent networks creation.
@@ -57,7 +58,7 @@ var networkCmd = APIEndpoint{
 	Path: "networks/{networkName}",
 
 	Delete: APIEndpointAction{Handler: networkDelete, AccessHandler: allowPermission(auth.ObjectTypeNetwork, auth.EntitlementCanEdit, "networkName")},
-	Get:    APIEndpointAction{Handler: networkGet, AccessHandler: allowPermission(auth.ObjectTypeNetwork, auth.EntitlementCanView, "networkName")},
+	Get:    APIEndpointAction{Handler: networkGet, AccessHandler: allowAuthenticated},
 	Patch:  APIEndpointAction{Handler: networkPatch, AccessHandler: allowPermission(auth.ObjectTypeNetwork, auth.EntitlementCanEdit, "networkName")},
 	Post:   APIEndpointAction{Handler: networkPost, AccessHandler: allowPermission(auth.ObjectTypeNetwork, auth.EntitlementCanEdit, "networkName")},
 	Put:    APIEndpointAction{Handler: networkPut, AccessHandler: allowPermission(auth.ObjectTypeNetwork, auth.EntitlementCanEdit, "networkName")},
@@ -210,6 +211,7 @@ func networksGet(d *Daemon, r *http.Request) response.Response {
 	mustLoadObjects := recursion || (clauses != nil && len(clauses.Clauses) > 0)
 
 	allProjects := util.IsTrue(r.FormValue("all-projects"))
+	unmanagedNetworkNames := []string{}
 
 	var networkNames map[string][]string
 
@@ -239,37 +241,45 @@ func networksGet(d *Daemon, r *http.Request) response.Response {
 
 	// Get list of actual network interfaces on the host as well if the effective project is Default.
 	if projectName == api.ProjectDefaultName {
-		ifaces, err := net.Interfaces()
-		if err != nil {
-			return response.InternalError(err)
-		}
-
-		for _, iface := range ifaces {
-			// Ignore veth pairs (for performance reasons).
-			if strings.HasPrefix(iface.Name, "veth") {
-				continue
+		if s.OS.IncusOS != nil {
+			ns, err := s.OS.IncusOS.GetSystemNetwork()
+			if err != nil {
+				return response.InternalError(err)
 			}
 
-			// Append to the list of networks if a managed network of same name doesn't exist.
-			if !slices.Contains(networkNames[projectName], iface.Name) {
-				networkNames[projectName] = append(networkNames[projectName], iface.Name)
+			// Get the interfaces.
+			for _, iface := range ns.State.GetInterfaceNamesByRole("instances") {
+				// Append to the list of networks if a managed network of same name doesn't exist.
+				if !slices.Contains(networkNames[projectName], iface) {
+					networkNames[projectName] = append(networkNames[projectName], iface)
+					unmanagedNetworkNames = append(unmanagedNetworkNames, iface)
+				}
+			}
+		} else {
+			ifaces, err := net.Interfaces()
+			if err != nil {
+				return response.InternalError(err)
+			}
+
+			for _, iface := range ifaces {
+				// Ignore veth pairs (for performance reasons).
+				if strings.HasPrefix(iface.Name, "veth") {
+					continue
+				}
+
+				// Append to the list of networks if a managed network of same name doesn't exist.
+				if !slices.Contains(networkNames[projectName], iface.Name) {
+					networkNames[projectName] = append(networkNames[projectName], iface.Name)
+					unmanagedNetworkNames = append(unmanagedNetworkNames, iface.Name)
+				}
 			}
 		}
 	}
 
-	userHasPermission, err := s.Authorizer.GetPermissionChecker(r.Context(), r, auth.EntitlementCanView, auth.ObjectTypeNetwork)
-	if err != nil {
-		return response.InternalError(err)
-	}
-
 	linkResults := make([]string, 0)
 	fullResults := make([]api.Network, 0)
 	for projectName, networks := range networkNames {
 		for _, networkName := range networks {
-			if !userHasPermission(auth.ObjectNetwork(projectName, networkName)) {
-				continue
-			}
-
 			if mustLoadObjects {
 				netInfo, err := doNetworkGet(s, r, s.ServerClustered, projectName, reqProject.Config, networkName)
 				if err != nil {
@@ -289,7 +299,12 @@ func networksGet(d *Daemon, r *http.Request) response.Response {
 
 				fullResults = append(fullResults, netInfo)
 			} else {
-				if !project.NetworkAllowed(reqProject.Config, networkName, true) {
+				ok, err := canAccessNetwork(s, r, projectName, reqProject.Config, networkName, !slices.Contains(unmanagedNetworkNames, networkName))
+				if err != nil {
+					return response.SmartError(err)
+				}
+
+				if !ok {
 					continue
 				}
 			}
@@ -368,7 +383,12 @@ func networksPost(d *Daemon, r *http.Request) response.Response {
 	}
 
 	if req.Name == "none" {
-		return response.BadRequest(errors.New("Network name 'none' is not valid"))
+		return response.BadRequest(errors.New("Invalid network name: 'none' is a reserved name"))
+	}
+
+	err = validate.IsAPIName(req.Name, false)
+	if err != nil {
+		return response.BadRequest(fmt.Errorf("Invalid network name: %w", err))
 	}
 
 	// Check if project allows access to network.
@@ -393,9 +413,10 @@ func networksPost(d *Daemon, r *http.Request) response.Response {
 		return response.BadRequest(err)
 	}
 
+	// Driver specific name validation.
 	err = netType.ValidateName(req.Name)
 	if err != nil {
-		return response.BadRequest(err)
+		return response.BadRequest(fmt.Errorf("Invalid network name: %w", err))
 	}
 
 	netTypeInfo := netType.Info()
@@ -465,6 +486,11 @@ func networksPost(d *Daemon, r *http.Request) response.Response {
 			}
 		}
 
+		// Make sure that no description is set through the member-specific path.
+		if req.Description != "" {
+			return response.BadRequest(errors.New("The network description cannot be set for a specific member"))
+		}
+
 		exists := false
 		err = s.DB.Cluster.Transaction(r.Context(), func(ctx context.Context, tx *db.ClusterTx) error {
 			_, err := tx.GetNetworkID(ctx, projectName, req.Name)
@@ -487,14 +513,6 @@ func networksPost(d *Daemon, r *http.Request) response.Response {
 			if err != nil {
 				logger.Error("Failed to add network to authorizer", logger.Ctx{"name": req.Name, "project": projectName, "error": err})
 			}
-
-			n, err := network.LoadByName(s, projectName, req.Name)
-			if err != nil {
-				return response.SmartError(fmt.Errorf("Failed loading network: %w", err))
-			}
-
-			requestor := request.CreateRequestor(r)
-			s.Events.SendLifecycle(projectName, lifecycle.NetworkCreated.Event(n, requestor, nil))
 		}
 
 		return resp
@@ -533,7 +551,7 @@ func networksPost(d *Daemon, r *http.Request) response.Response {
 				for _, member := range members {
 					// Don't pass in any config, as these nodes don't have any node-specific
 					// config and we don't want to create duplicate global config.
-					err = tx.CreatePendingNetwork(ctx, member.Name, projectName, req.Name, req.Description, netType.DBType(), nil)
+					err = tx.CreatePendingNetwork(ctx, member.Name, projectName, req.Name, "", netType.DBType(), nil)
 					if err != nil && !errors.Is(err, db.ErrAlreadyDefined) {
 						return fmt.Errorf("Failed creating pending network for member %q: %w", member.Name, err)
 					}
@@ -550,14 +568,6 @@ func networksPost(d *Daemon, r *http.Request) response.Response {
 			if err != nil {
 				logger.Error("Failed to add network to authorizer", logger.Ctx{"name": req.Name, "project": projectName, "error": err})
 			}
-
-			n, err := network.LoadByName(s, projectName, req.Name)
-			if err != nil {
-				return response.SmartError(fmt.Errorf("Failed loading network: %w", err))
-			}
-
-			requestor := request.CreateRequestor(r)
-			s.Events.SendLifecycle(projectName, lifecycle.NetworkCreated.Event(n, requestor, nil))
 		}
 
 		err = networksPostCluster(r.Context(), s, projectName, netInfo, req, clientType, netType)
@@ -565,6 +575,14 @@ func networksPost(d *Daemon, r *http.Request) response.Response {
 			return response.SmartError(err)
 		}
 
+		n, err := network.LoadByName(s, projectName, req.Name)
+		if err != nil {
+			return response.SmartError(fmt.Errorf("Failed loading network: %w", err))
+		}
+
+		requestor := request.CreateRequestor(r)
+		s.Events.SendLifecycle(projectName, lifecycle.NetworkCreated.Event(n, requestor, nil))
+
 		return resp
 	}
 
@@ -703,6 +721,12 @@ func networksPostCluster(ctx context.Context, s *state.State, projectName string
 			return err
 		}
 
+		// Set the network description if provided
+		err = tx.UpdateNetworkDescription(networkID, req.Description)
+		if err != nil {
+			return err
+		}
+
 		// Assume failure unless we succeed later on.
 		return tx.NetworkErrored(projectName, req.Name)
 	})
@@ -810,7 +834,7 @@ func doNetworksCreate(ctx context.Context, s *state.State, n network.Network, cl
 	}
 
 	// Validate so that when run on a cluster node the full config (including node specific config) is checked.
-	err := n.Validate(validateConfig)
+	err := n.Validate(validateConfig, clientType)
 	if err != nil {
 		return err
 	}
@@ -930,6 +954,42 @@ func networkGet(d *Daemon, r *http.Request) response.Response {
 	return response.SyncResponseETag(true, &n, etag)
 }
 
+// canAccessNetwork checks if the network can be viewed/accessed by the user.
+func canAccessNetwork(s *state.State, r *http.Request, projectName string, projectConfig map[string]string, networkName string, managed bool) (bool, error) {
+	// Don't allow retrieving info about the local server interfaces when not using default project.
+	if projectName != api.ProjectDefaultName && !managed {
+		return false, nil
+	}
+
+	// Check for basic access.
+	if managed {
+		userHasPermission, err := s.Authorizer.GetPermissionChecker(r.Context(), r, auth.EntitlementCanView, auth.ObjectTypeNetwork)
+		if err != nil {
+			return false, err
+		}
+
+		if !userHasPermission(auth.ObjectNetwork(projectName, networkName)) {
+			return false, nil
+		}
+	} else {
+		userHasResourcesPermission, err := s.Authorizer.GetPermissionChecker(r.Context(), r, auth.EntitlementCanViewResources, auth.ObjectTypeServer)
+		if err != nil {
+			return false, err
+		}
+
+		if !userHasResourcesPermission(auth.ObjectServer()) {
+			return false, nil
+		}
+	}
+
+	// Check if project allows access to network.
+	if !project.NetworkAllowed(projectConfig, networkName, managed) {
+		return false, nil
+	}
+
+	return true, nil
+}
+
 // doNetworkGet returns information about the specified network.
 // If the network being requested is a managed network and allNodes is true then node specific config is removed.
 // Otherwise if allNodes is false then the network's local status is returned.
@@ -945,16 +1005,17 @@ func doNetworkGet(s *state.State, r *http.Request, allNodes bool, projectName st
 		return api.Network{}, fmt.Errorf("Failed loading network: %w", err)
 	}
 
-	// Don't allow retrieving info about the local server interfaces when not using default project.
-	if projectName != api.ProjectDefaultName && n == nil {
-		return api.Network{}, api.StatusErrorf(http.StatusNotFound, "Network not found")
+	// Validate access.
+	ok, err := canAccessNetwork(s, r, projectName, reqProjectConfig, networkName, n != nil)
+	if err != nil {
+		return api.Network{}, err
 	}
 
-	// Check if project allows access to network.
-	if !project.NetworkAllowed(reqProjectConfig, networkName, n != nil && n.IsManaged()) {
+	if !ok {
 		return api.Network{}, api.StatusErrorf(http.StatusNotFound, "Network not found")
 	}
 
+	// Get OS network details.
 	osInfo, _ := net.InterfaceByName(networkName)
 
 	// Quick check.
@@ -1235,9 +1296,16 @@ func networkPost(d *Daemon, r *http.Request) response.Response {
 		return response.BadRequest(errors.New("New network name not provided"))
 	}
 
+	// Perform generic name validation.
+	err = validate.IsAPIName(req.Name, false)
+	if err != nil {
+		return response.BadRequest(fmt.Errorf("Invalid network name: %w", err))
+	}
+
+	// Perform driver-specific name validation.
 	err = n.ValidateName(req.Name)
 	if err != nil {
-		return response.BadRequest(err)
+		return response.BadRequest(fmt.Errorf("Invalid network name: %w", err))
 	}
 
 	// Check network isn't in use.
@@ -1383,9 +1451,11 @@ func networkPut(d *Daemon, r *http.Request) response.Response {
 		return response.BadRequest(err)
 	}
 
+	clientType := clusterRequest.UserAgentClientType(r.Header.Get("User-Agent"))
+
 	// In clustered mode, we differentiate between node specific and non-node specific config keys based on
 	// whether the user has specified a target to apply the config to.
-	if s.ServerClustered {
+	if s.ServerClustered && clientType == clusterRequest.ClientTypeNormal {
 		curConfig := n.Config()
 		changedConfig := make(map[string]string, len(req.Config))
 		for key, value := range req.Config {
@@ -1413,12 +1483,13 @@ func networkPut(d *Daemon, r *http.Request) response.Response {
 		}
 	}
 
-	clientType := clusterRequest.UserAgentClientType(r.Header.Get("User-Agent"))
-
 	resp = doNetworkUpdate(n, req, targetNode, clientType, r.Method, s.ServerClustered)
 
-	requestor := request.CreateRequestor(r)
-	s.Events.SendLifecycle(projectName, lifecycle.NetworkUpdated.Event(n, requestor, nil))
+	// Send a single update event when the server is clustered.
+	if !s.ServerClustered || (s.ServerClustered && clientType == clusterRequest.ClientTypeNormal) {
+		requestor := request.CreateRequestor(r)
+		s.Events.SendLifecycle(projectName, lifecycle.NetworkUpdated.Event(n, requestor, nil))
+	}
 
 	return resp
 }
@@ -1496,7 +1567,7 @@ func doNetworkUpdate(n network.Network, req api.NetworkPut, targetNode string, c
 	}
 
 	// Validate the merged configuration.
-	err := n.Validate(req.Config)
+	err := n.Validate(req.Config, clientType)
 	if err != nil {
 		return response.BadRequest(err)
 	}
@@ -1691,7 +1762,7 @@ func networkStartup(s *state.State) error {
 		}
 
 		netConfig := n.Config()
-		err = n.Validate(netConfig)
+		err = n.Validate(netConfig, clusterRequest.ClientTypeNormal)
 		if err != nil {
 			return fmt.Errorf("Failed validating: %w", err)
 		}
